@@ -1,8 +1,5 @@
-from __future__ import unicode_literals
-
-from mopidy import backend
-
 import pykka
+from mopidy import backend
 
 from .client import iTunesPodcastClient
 from .library import iTunesPodcastLibraryProvider
@@ -10,9 +7,9 @@ from .library import iTunesPodcastLibraryProvider
 
 class iTunesPodcastBackend(pykka.ThreadingActor, backend.Backend):
 
-    uri_schemes = ['podcast+itunes']
+    uri_schemes = ["podcast+itunes"]
 
     def __init__(self, config, audio):
-        super(iTunesPodcastBackend, self).__init__()
+        super().__init__()
         self.client = iTunesPodcastClient(config)
         self.library = iTunesPodcastLibraryProvider(config, self)
